==> odata-client-msgraph-beta-0.1.26-sources.jar: odata/msgraph/client/beta/entity/CertificateBasedAuthConfiguration.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFields;

import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.complex.CertificateAuthority;
import odata.msgraph.client.beta.schema.SchemaInfo;

@JsonPropertyOrder({
    "@odata.type", 
    "certificateAuthorities"})
@JsonInclude(Include.NON_NULL)
public class CertificateBasedAuthConfiguration extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.certificateBasedAuthConfiguration";
    }

    @JsonProperty("certificateAuthorities")
    protected List<CertificateAuthority> certificateAuthorities;

    @JsonProperty("certificateAuthorities@nextLink")
    protected String certificateAuthoritiesNextLink;

    protected CertificateBasedAuthConfiguration() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderCertificateBasedAuthConfiguration() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private List<CertificateAuthority> certificateAuthorities;
        private String certificateAuthoritiesNextLink;
        private ChangedFields changedFields = new ChangedFields();

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder certificateAuthorities(List<CertificateAuthority> certificateAuthorities) {
            this.certificateAuthorities = certificateAuthorities;
            this.changedFields = changedFields.add("certificateAuthorities");
            return this;
        }

        public Builder certificateAuthorities(CertificateAuthority... certificateAuthorities) {
            return certificateAuthorities(Arrays.asList(certificateAuthorities));
        }

        public Builder certificateAuthoritiesNextLink(String certificateAuthoritiesNextLink) {
            this.certificateAuthoritiesNextLink = certificateAuthoritiesNextLink;
            this.changedFields = changedFields.add("certificateAuthorities");
            return this;
        }

        public CertificateBasedAuthConfiguration build() {
            CertificateBasedAuthConfiguration _x = new CertificateBasedAuthConfiguration();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFields();
            _x.odataType = "microsoft.graph.certificateBasedAuthConfiguration";
            _x.id = id;
            _x.certificateAuthorities = certificateAuthorities;
            _x.certificateAuthoritiesNextLink = certificateAuthoritiesNextLink;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id.toString()));
        }
    }

    @Property(name="certificateAuthorities")
    @JsonIgnore
    public CollectionPage<CertificateAuthority> getCertificateAuthorities() {
        return new CollectionPage<CertificateAuthority>(contextPath, CertificateAuthority.class, certificateAuthorities, Optional.ofNullable(certificateAuthoritiesNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    @Property(name="certificateAuthorities")
    @JsonIgnore
    public CollectionPage<CertificateAuthority> getCertificateAuthorities(HttpRequestOptions options) {
        return new CollectionPage<CertificateAuthority>(contextPath, CertificateAuthority.class, certificateAuthorities, Optional.ofNullable(certificateAuthoritiesNextLink), SchemaInfo.INSTANCE, Collections.emptyList(), options);
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFields();
        }
        unmappedFields.put(name, value);
    }

    @Override
    @JsonIgnore
    public UnmappedFields getUnmappedFields() {
        return unmappedFields == null ? new UnmappedFields() : unmappedFields;
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public CertificateBasedAuthConfiguration patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        CertificateBasedAuthConfiguration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public CertificateBasedAuthConfiguration put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        CertificateBasedAuthConfiguration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private CertificateBasedAuthConfiguration _copy() {
        CertificateBasedAuthConfiguration _x = new CertificateBasedAuthConfiguration();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields;
        _x.odataType = odataType;
        _x.id = id;
        _x.certificateAuthorities = certificateAuthorities;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CertificateBasedAuthConfiguration[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("certificateAuthorities=");
        b.append(this.certificateAuthorities);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}

==> odata-client-msgraph-beta-0.2.1-sources.jar: odata/msgraph/client/beta/entity/CertificateBasedAuthConfiguration.java <==
package odata.msgraph.client.beta.entity;

import com.fasterxml.jackson.annotation.JsonAnyGetter;
import com.fasterxml.jackson.annotation.JsonAnySetter;
import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonInclude;
import com.fasterxml.jackson.annotation.JsonInclude.Include;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.fasterxml.jackson.annotation.JsonPropertyOrder;
import com.github.davidmoten.odata.client.ClientException;
import com.github.davidmoten.odata.client.CollectionPage;
import com.github.davidmoten.odata.client.HttpRequestOptions;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.ODataEntityType;
import com.github.davidmoten.odata.client.RequestOptions;
import com.github.davidmoten.odata.client.UnmappedFields;
import com.github.davidmoten.odata.client.Util;
import com.github.davidmoten.odata.client.annotation.Property;
import com.github.davidmoten.odata.client.internal.ChangedFields;
import com.github.davidmoten.odata.client.internal.RequestHelper;
import com.github.davidmoten.odata.client.internal.UnmappedFieldsImpl;

import java.lang.Object;
import java.lang.Override;
import java.lang.String;
import java.lang.StringBuilder;
import java.util.Arrays;
import java.util.Collections;
import java.util.List;
import java.util.Optional;

import odata.msgraph.client.beta.complex.CertificateAuthority;

@JsonPropertyOrder({
    "@odata.type", 
    "certificateAuthorities"})
@JsonInclude(Include.NON_NULL)
public class CertificateBasedAuthConfiguration extends Entity implements ODataEntityType {

    @Override
    public String odataTypeName() {
        return "microsoft.graph.certificateBasedAuthConfiguration";
    }

    @JsonProperty("certificateAuthorities")
    protected List<CertificateAuthority> certificateAuthorities;

    @JsonProperty("certificateAuthorities@nextLink")
    protected String certificateAuthoritiesNextLink;

    protected CertificateBasedAuthConfiguration() {
        super();
    }

    /**
     * Returns a builder which is used to create a new
     * instance of this class (given that this class is immutable).
     *
     * @return a new Builder for this class
     */
    // Suffix used on builder factory method to differentiate the method
    // from static builder methods on superclasses
    public static Builder builderCertificateBasedAuthConfiguration() {
        return new Builder();
    }

    public static final class Builder {
        private String id;
        private List<CertificateAuthority> certificateAuthorities;
        private String certificateAuthoritiesNextLink;
        private ChangedFields changedFields = ChangedFields.EMPTY;

        Builder() {
            // prevent instantiation
        }

        public Builder id(String id) {
            this.id = id;
            this.changedFields = changedFields.add("id");
            return this;
        }

        public Builder certificateAuthorities(List<CertificateAuthority> certificateAuthorities) {
            this.certificateAuthorities = certificateAuthorities;
            this.changedFields = changedFields.add("certificateAuthorities");
            return this;
        }

        public Builder certificateAuthorities(CertificateAuthority... certificateAuthorities) {
            return certificateAuthorities(Arrays.asList(certificateAuthorities));
        }

        public Builder certificateAuthoritiesNextLink(String certificateAuthoritiesNextLink) {
            this.certificateAuthoritiesNextLink = certificateAuthoritiesNextLink;
            this.changedFields = changedFields.add("certificateAuthorities");
            return this;
        }

        public CertificateBasedAuthConfiguration build() {
            CertificateBasedAuthConfiguration _x = new CertificateBasedAuthConfiguration();
            _x.contextPath = null;
            _x.changedFields = changedFields;
            _x.unmappedFields = new UnmappedFieldsImpl();
            _x.odataType = "microsoft.graph.certificateBasedAuthConfiguration";
            _x.id = id;
            _x.certificateAuthorities = certificateAuthorities;
            _x.certificateAuthoritiesNextLink = certificateAuthoritiesNextLink;
            return _x;
        }
    }

    @Override
    @JsonIgnore
    public ChangedFields getChangedFields() {
        return changedFields;
    }

    @Override
    public void postInject(boolean addKeysToContextPath) {
        if (addKeysToContextPath && id != null) {
            contextPath = contextPath.clearQueries().addKeys(new NameValue(id, String.class));
        }
    }

    @Property(name="certificateAuthorities")
    @JsonIgnore
    public CollectionPage<CertificateAuthority> getCertificateAuthorities() {
        return new CollectionPage<CertificateAuthority>(contextPath, CertificateAuthority.class, this.certificateAuthorities, Optional.ofNullable(certificateAuthoritiesNextLink), Collections.emptyList(), HttpRequestOptions.EMPTY);
    }

    public CertificateBasedAuthConfiguration withCertificateAuthorities(List<CertificateAuthority> certificateAuthorities) {
        CertificateBasedAuthConfiguration _x = _copy();
        _x.changedFields = changedFields.add("certificateAuthorities");
        _x.odataType = Util.nvl(odataType, "microsoft.graph.certificateBasedAuthConfiguration");
        _x.certificateAuthorities = certificateAuthorities;
        return _x;
    }

    @Property(name="certificateAuthorities")
    @JsonIgnore
    public CollectionPage<CertificateAuthority> getCertificateAuthorities(HttpRequestOptions options) {
        return new CollectionPage<CertificateAuthority>(contextPath, CertificateAuthority.class, this.certificateAuthorities, Optional.ofNullable(certificateAuthoritiesNextLink), Collections.emptyList(), options);
    }

    public CertificateBasedAuthConfiguration withUnmappedField(String name, Object value) {
        CertificateBasedAuthConfiguration _x = _copy();
        _x.setUnmappedField(name, value);
        return _x;
    }

    @JsonAnySetter
    private void setUnmappedField(String name, Object value) {
        if (unmappedFields == null) {
            unmappedFields = new UnmappedFieldsImpl();
        }
        unmappedFields.put(name, value);
    }

    @JsonAnyGetter
    private UnmappedFieldsImpl unmappedFields() {
        return unmappedFields == null ? UnmappedFieldsImpl.EMPTY : unmappedFields;
    }

    @Override
    public UnmappedFields getUnmappedFields() {
        return unmappedFields();
    }

    /**
     * Submits only changed fields for update and returns an 
     * immutable copy of {@code this} with changed fields reset.
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public CertificateBasedAuthConfiguration patch() {
        RequestHelper.patch(this, contextPath, RequestOptions.EMPTY);
        CertificateBasedAuthConfiguration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    /**
     * Submits all fields for update and returns an immutable copy of {@code this}
     * with changed fields reset (they were ignored anyway).
     *
     * @return a copy of {@code this} with changed fields reset
     * @throws ClientException if HTTP response is not as expected
     */
    public CertificateBasedAuthConfiguration put() {
        RequestHelper.put(this, contextPath, RequestOptions.EMPTY);
        CertificateBasedAuthConfiguration _x = _copy();
        _x.changedFields = null;
        return _x;
    }

    private CertificateBasedAuthConfiguration _copy() {
        CertificateBasedAuthConfiguration _x = new CertificateBasedAuthConfiguration();
        _x.contextPath = contextPath;
        _x.changedFields = changedFields;
        _x.unmappedFields = unmappedFields.copy();
        _x.odataType = odataType;
        _x.id = id;
        _x.certificateAuthorities = certificateAuthorities;
        return _x;
    }

    @Override
    public String toString() {
        StringBuilder b = new StringBuilder();
        b.append("CertificateBasedAuthConfiguration[");
        b.append("id=");
        b.append(this.id);
        b.append(", ");
        b.append("certificateAuthorities=");
        b.append(this.certificateAuthorities);
        b.append("]");
        b.append(",unmappedFields=");
        b.append(unmappedFields);
        b.append(",odataType=");
        b.append(odataType);
        return b.toString();
    }
}
